#!/bin/bash
if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 1>&2
   exit 1
fi


# ---------------------------------------------------------------------------- #

GENERATED_UID_FILE="/home/rtls/rtls_server_uid/rtls_server_uid_gen.txt"
AWS_UID_FILE="/home/rtls/rtls_server_uid/rtls_server_uid_aws.txt"
SERVER_UID_FILE="/home/rtls/rtls_server_uid/rtls_server_uid.txt"

# ---------------------------------------------------------------------------- #

mkdir -p /home/rtls/rtls_server_uid

if [ -f "/sys/hypervisor/uuid" ] || [ $(cat /sys/devices/virtual/dmi/id/board_asset_tag) ]; then

    echo "file exists on the t3 instance: $(cat /sys/devices/virtual/dmi/id/board_asset_tag)"
    AWS_INSTANCE_ID_CHECK="$(wget -q -O - http://169.254.169.254/latest/meta-data/instance-id)"

    if [ -z "$AWS_INSTANCE_ID_CHECK" ]; then

        TOKEN="$(curl -s -X PUT "http://169.254.169.254/latest/api/token" -H "X-aws-ec2-metadata-token-ttl-seconds: 21600")"

        if [ -n "$TOKEN" ]; then

            AWS_INSTANCE_ID_CHECK="$(curl -s -H "X-aws-ec2-metadata-token: $TOKEN" http://169.254.169.254/latest/meta-data/instance-id)"
        fi
    fi
fi


if [ -n "$AWS_INSTANCE_ID_CHECK" ]; then

    PREVIOUS_INSTANCE_UID_CHECK="$(cat $SERVER_UID_FILE)"

elif [ ! -f "$SERVER_UID_FILE" ]; then

    NEW_SERVER_UID=$(uuidgen)
    echo 'NEW_SERVER_UID='$NEW_SERVER_UID

    chattr -i "$GENERATED_UID_FILE"
    rm -rf "$GENERATED_UID_FILE"

    echo -e "$NEW_SERVER_UID" > "$GENERATED_UID_FILE"
    echo -e "$NEW_SERVER_UID" > "$SERVER_UID_FILE"
    chattr +i "$SERVER_UID_FILE"
    echo "Use local server UID - $(cat $SERVER_UID_FILE)"

elif [ -f "$SERVER_UID_FILE" ]; then

    echo "Use old server UID - $(cat $SERVER_UID_FILE)"

fi


if [ "$AWS_INSTANCE_ID_CHECK" != "$PREVIOUS_INSTANCE_UID_CHECK" ]; then

    echo "The AWS UID has been modified - write new UID to $SERVER_UID_FILE"

    chattr -i "$AWS_UID_FILE"
    rm -rf "$AWS_UID_FILE"

    chattr -i "$SERVER_UID_FILE"
    rm -rf "$SERVER_UID_FILE"

    NEW_SERVER_UID=$AWS_INSTANCE_ID_CHECK
    echo -e "$NEW_SERVER_UID" > "$AWS_UID_FILE"
    echo -e "$NEW_SERVER_UID" > "$SERVER_UID_FILE"
    chattr +i "$SERVER_UID_FILE"

else
    echo "AWS Server UID has NOT been changed - keep current server UID: $PREVIOUS_INSTANCE_UID_CHECK"
fi
